# BattleMetrics API Wrapper

[![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff)
![PyPI - Version](https://img.shields.io/pypi/v/battlemetrics)
![PyPI - Downloads](https://img.shields.io/pypi/dm/battlemetrics)


An async Python wrapper for the BattleMetrics API with full type safety using Pydantic models.

>[!CAUTION]
> This API Wrapper is very new and partly untested. Please report any issues instantly.

>[!NOTE]
> Since the BattleMetrics API Documentation is partly finished not every endpoint might be included. Make an Issue Report for any missing endpoints.

## Installation

To install the latest published version off of PyPI, you can run the following command:

```bash
pip install battlemetrics
```

To install the development version from GitHub (requires Git):
```bash
pip install git+https://github.com/OseSem/battlemetrics
```
